==> apache-cloudstack-4.17.0.1-src.tar.bz2: apache-cloudstack-4.17.0.1-src/api/src/main/java/com/cloud/network/as/AutoScaleVmProfile.java <==
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

package com.cloud.network.as;

import java.util.List;

import org.apache.cloudstack.acl.ControlledEntity;
import org.apache.cloudstack.api.Displayable;
import org.apache.cloudstack.api.InternalIdentity;

import com.cloud.utils.Pair;

/**
 * AutoScaleVmProfile
 */
public interface AutoScaleVmProfile extends ControlledEntity, InternalIdentity, Displayable {

    @Override
    public long getId();

    public String getUuid();

    public Long getZoneId();

    public Long getServiceOfferingId();

    public Long getTemplateId();

    public String getOtherDeployParams();

    List<Pair<String, String>> getCounterParams();

    public Integer getDestroyVmGraceperiod();

    public long getAutoScaleUserId();

    @Override
    boolean isDisplay();

}

==> apache-cloudstack-4.18.0.0-src.tar.bz2: apache-cloudstack-4.18.0.0-src/api/src/main/java/com/cloud/network/as/AutoScaleVmProfile.java <==
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

package com.cloud.network.as;

import java.util.List;

import org.apache.cloudstack.acl.ControlledEntity;
import org.apache.cloudstack.api.Displayable;
import org.apache.cloudstack.api.InternalIdentity;

import com.cloud.utils.Pair;

/**
 * AutoScaleVmProfile
 */
public interface AutoScaleVmProfile extends ControlledEntity, InternalIdentity, Displayable {

    @Override
    public long getId();

    String getUserData();

    public String getUuid();

    public Long getZoneId();

    public Long getServiceOfferingId();

    public Long getTemplateId();

    public String getOtherDeployParams();

    public List<Pair<String, String>> getOtherDeployParamsList();

    List<Pair<String, String>> getCounterParams();

    public Integer getExpungeVmGracePeriod();

    public Long getAutoScaleUserId();

    @Override
    boolean isDisplay();

}
